Description Usage Format Fields Methods
R6 class for the e_production
1 |
An R6Class generator object
serveraddressStores address of your lightning server.
sessionidStores id of your current session on the server.
urlStores url of the last visualization created by this object.
autoopenChecks if the server is automatically opening the visualizations.
notebookChecks if the server is in the jupyter notebook mode.
For full documentation of each method go to https://github.com/lightning-viz/lightining-r/
new(serveraddress)This method is used to create object of this class with serveraddress as address of the server object is connecting to.
sethost(serveraddress)This method changes server that you are contacting with to serveraddress.
createsession(sessionname = "")This method creates new session on the server with optionally given name in sessionname.
usesession(sessionid)This method changes currently used session on the server to the one with id given in sessionid parameter.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.